@@ -2,27 +2,31 @@
 # SPDX-License-Identifier: GPL-3.0-only
 
 """
-Pane plot method
-----------------
+Composition: ``panes``
+----------------------
 """
 
 
 import numpy as np
-from math import floor, ceil
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 
-from alexandria.paths import home
+from math import floor, ceil
+from copy import deepcopy as dc
 
 from mpl_plotter import figure
 from mpl_plotter.two_d import line
 from mpl_plotter.two_d.comparison import comparison
 
+from mpl_plotter.utils import home
+
 
 def panes(x,
           y,
           f=None,
           fig=None,
+          shape=None,
+          figsize=None,
           show=False,
           rows=1,
           top=None,
@@ -33,71 +37,125 @@ def panes(x,
           hspace=None,
           **kwargs):
     """
-    Panes
-    -----
+    .. raw:: latex
 
-    # Inputs
-    The panes function supports numerical inputs in the following forms:
-    |   x                              |   y                               |  result  |  notes                                          |
-    |  ---                             |  ---                              |  ---     |  ---                                            |
-    |  array                           |  array                            |  11      |                                                 |
-    |  array                           |  [array, array]                   |  12      |  Both `y`s share `x`                            |
-    |  [n*[array]]                     |  [n*[array]]                      |  1n      |  Each `y` has an `x`                            |
-    |  array                           |  [array, array]                   |  21      |  Both `y`s share `x`                            |
-    |  [array, array]                  |  [array, array]                   |  21      |  Each `y` has an `x`                            |
-    |  array                           |  [n*[array], n*[array]]           |  2n      |  All curves in all (2) panes share a single `x` |
-    |  [array, array]                  |  [n*[array], n*[array]]           |  2n      |  All curves in each pane share an `x`           |
-    |  [n*[array], n*[array]]          |  [n*[array], n*[array]]           |  2n      |  All curves in all (2) panes have their own `x` |
-    |  [n*[array], ... up to m]        |  [n*[array], ... up to m]         |  mn      |  All curves in all panes have their own `x`     |
+        \subsection*{Data Input}
 
-    where
+    The table below displays the supported numerical input combinations, where:
 
-    * array:  List or NumPy array with numerical values
-    * [...]:  List containing ...
-    * result: <panes><curves per pane>
+    - array:  List or NumPy array with numerical values
+    - [...]:  List containing ...
+    - result: <curves>
 
-    # Arguments
-    Arguments are internally classified as FIGURE arguments, PLURAL arguments
-    and CURVE arguments, namely:
+    .. list-table:: Valid input combinations.
+        :widths: 25 25 10 40
+        :header-rows: 1
+
+        * - ``x``
+          - ``y``
+          - Result
+          - Notes
+        * - array
+          - array
+          - 11
+          -
+        * - array                   
+          - [array, array]          
+          - 12
+          - Both ``y`` share ``x``                         
+        * - [n*[array]]             
+          - [n*[array]]             
+          - 1n
+          - Each ``y`` has an ``x``                           
+        * - array                   
+          - [array, array]          
+          - 21
+          - Both ``y`` share ``x``                           
+        * - [array, array]          
+          - [array, array]          
+          - 21
+          - Each ``y`` has an ``x``                           
+        * - array                   
+          - [n*[array], n*[array]]  
+          - 2n
+          - All curves in all (2) panes share a single ``x``
+        * - [array, array]          
+          - [n*[array], n*[array]]  
+          - 2n
+          - All curves in each pane share an ``x``          
+        * - [n*[array], n*[array]]  
+          - [n*[array], n*[array]]  
+          - 2n
+          - All curves in all (2) panes have their own ``x``
+        * - [n*[array], ... up to m]
+          - [n*[array], ... up to m]
+          - mn
+          - All curves in all panes have their own ``x``    
+
+    .. raw:: latex
+
+        \subsubsection*{Argument Classification}
+    
+    Arguments are internally classified as **figure**, **legend**, **plural** and **curve** arguments, namely:
 
     * Figure arguments
-        Select few arguments which may be input only once in the plotting process, so as
-        to avoid conflicts. Ieg: passing `grid=True` twice (`plt.grid(...)`) will result
-        in no grid being drawn.
-        These are removed from the keyword arguments and used in the last `comparison` call.
 
-    * Special arguments
-        Select few arguments (ieg: `plot_labels`), which satisfy the condition of being
-            `lists with a length different to that of y`
-        and which, for aesthetic purposes, must be applied only once.
+      Arguments which may be input only once in the plotting process, so as
+      to avoid conflicts (eg: passing ``grid=True`` twice (``plt.grid(...)``) will result
+      in no grid being drawn). These are removed from the keyword arguments and applied in 
+      the last ``comparison`` call.
 
-        In the case of `plot_labels`, if `plot_labels` is a list of length different to that
-        of `y`, it is assumed that
-            - The nth curve of each pane shares a label with the nth curve of all other panes
-        and so a legend displaying the labels of the last pane will be displayed.
+    * Legend arguments
+
+      These are ``plot_label/s``, which to avoid redundancy are applied in the last ``comparison``. 
+      This is done only if the number of curves is the same across all panes, and equal to the number 
+      of provided ``plot_labels``.
 
     * Plural arguments
-        Arguments with a keyword equal to any of the arguments which can be passed to the
-          `line`
-        2D plotter, in plural tense. The line plotter is chosen as it shares all general
-        arguments with the other 2D plotter functions.
-        The plural arguments are assumed to be
-          `lists of length equal to the number of panes`
-        and thus modify each pane. Ieg: x_tick_labels=[1, 2, 3] will set the tick labels
-        of the x axes to 1, 2 and 3 respectively in a 3-pane plot.
+
+      Arguments passed with any of the keywords accepted by all 2D plotters -that is, any keyword
+      which does **not** start with the name of its plotting class-, in plural tense.
+      These must be **lists** of length equal to the **number of panes**.
+      Each element in the list is the value of the keyword argument for each pane (eg: 
+      ``tick_labels_x=[1, 2, 3]`` will set the tick labels of the x axes to 1, 2 and 3 
+      respectively in a 3-pane plot).
 
     * Curve arguments
-        Curve arguments are passed as plurals to the comparison function, as they are
-          `lists with a length different to that of y`
-        (thus they can't apply to each pane) and they are assumed to have a length equal
-        to the number of curves in each plot.
 
+      Arguments passed as plurals to the comparison function. These are once more **lists**
+      containing the value of a keyword argument, passed in plural, for each curve following
+      the convention shown above for data input, such that passing
+      ``colors=[['red', 'blue'], ['green', 'red']]`` to a plot containing 2 panes with 2 curves
+      each will color the curves in the first pane red and blue, and those in the second green and red.
 
-    :type x:                list of list or list of np.ndarray or np.ndarray
-    :type y:                list of list or list of np.ndarray or np.ndarray
-    :type f:                list of function or list of plot
-    :type show:             bool
-    :type kwargs:           any
+    :param x:        Data
+    :param y:        Data
+    :param f:        List of plotting functions to use for each curve
+    :param fig:      Figure object on which to plot
+    :param figsize:  Figure size
+    :param show:     Whether to plt.show() after plotting (thereby finishing the plot)
+    :param rows:     Number of rows
+    :param top:      plt.subplots_adjust parameter
+    :param bottom:   plt.subplots_adjust parameter
+    :param left:     plt.subplots_adjust parameter
+    :param right:    plt.subplots_adjust parameter
+    :param wspace:   plt.subplots_adjust parameter
+    :param hspace:   plt.subplots_adjust parameter
+    :param kwargs:   MPL Plotter plotting class keyword arguments for further customization
+
+    :type x:         list of list or list of np.ndarray or np.ndarray
+    :type y:         list of list or list of np.ndarray or np.ndarray
+    :type f:         list of function or list of plot
+    :type fig:       matplotlib.figure.Figure
+    :type figsize:   tuple of float
+    :type show:      bool
+    :type rows:      int
+    :type top:       float
+    :type bottom:    float
+    :type left:      float
+    :type right:     float
+    :type wspace:    float
+    :type hspace:    float
     """
 
     ###############################
@@ -154,37 +212,48 @@ def panes(x,
         'legend',
         'legend_loc'
     ]
-    skeys   = [
+    lkeys   = [
         'plot_label',
         'plot_labels'
     ]
 
     # figure arguments ------------------------------------------------
-    fargs = {k: kwargs.pop(k) for k in list(set(fkeys) & set(list(kwargs.keys())))}
+    fargs = {k: kwargs.pop(k) for k in list(set(fkeys) & set(kwargs.keys()))}
 
     fargs['backend']    = fargs.pop('backend',    'Qt5Agg')
     fargs['legend_loc'] = fargs.pop('legend_loc', (0.875, 0.55))
 
     # legend arguments -----------------------------------------------
-    largs = {k: kwargs.pop(k) for k in list(kwargs.keys()) if k in skeys and len([kwargs[k]] if not isinstance(kwargs[k], list) else kwargs[k]) != n_plots}
-    fargs['legend'] = fargs.pop('legend',     len([k for k in largs.keys() if 'label' in k]) != 0)
+    largs = {k: kwargs.pop(k) for k in dc(kwargs).keys() if k in lkeys and len([kwargs[k]] if not isinstance(kwargs[k], list) else kwargs[k]) != n_plots}
+    fargs['legend'] = fargs.pop('legend', len([k for k in {**kwargs, **largs}.keys() if 'label' in k]) != 0)
 
     # plural arguments ------------------------------------------------
-    args  = line.__init__.__code__.co_varnames                        # Get line function parameters
-    plurals = [param + 's' for param in args]                         # Parameters: in plural
-    plurals = list(set(plurals) & set(list(kwargs.keys())))             # Intersection of kwargs keys and plurals
+    args    = line.__init__.__code__.co_varnames                        # Get line function arguments
+
+    ax_arg = lambda arg: arg[-2:] in ['_x', '_y']
+
+    plurals = [arg + 's' if not ax_arg(arg) else arg[:-2] + 's' + arg[-2:] for arg in args]
+
+    plurals = list(set(plurals) & set(kwargs.keys()))                   # Intersection of kwargs keys and plurals
     plurals = {k: kwargs.pop(k) for k in plurals}                       # Dictionary of plurals
 
     def plural(i):
         """
-        Get plurals parameters of the ith plot.
+        Get plural arguments of the ith plot.
 
         :param i: index
         """
-        return {k[:-1]: plurals[k][i] for k in list(plurals.keys())}
+
+        _args = {}
+
+        for k in plurals.keys():
+            _k = k[:-3] + k[-2:] if ax_arg(k) else k[:-1]
+            _args[_k] = plurals[k][i]
+
+        return _args
 
     # curve arguments ------------------------------------------------
-    cargs = {k: plurals.pop(k) for k in list(plurals.keys()) if isinstance(plurals[k], list) and len(plurals[k]) != n_plots}
+    cargs = {k: plurals.pop(k) for k in dc(plurals).keys() if isinstance(plurals[k], list) and (len(plurals[k]) != n_plots or all([isinstance(arg, list) for arg in plurals[k]]))}
 
     ###############################
     #           FIGURE            #
@@ -195,17 +264,20 @@ def panes(x,
     height = 3.5 if M == 1 else 4
 
     if fig is None:
-        fig = figure((5 * N, height * M), backend=fargs['backend'])
+        if figsize is None:
+            fig = figure((5 * N, height * M), backend=fargs['backend'])
+        else:
+            fig = figure(figsize)
 
     ###############################
     #            PLOT             #
     ###############################
 
-    shape = (M, N)
+    shape = (M, N) if shape is None else shape
     
     for n in range(n_plots):
-
-        coords = (floor(n/(M+1)), (n % (M+1)))
+        
+        coords = (floor(n/(N)), (n % (N)))
 
         ax_transient = plt.subplot2grid(shape,
                                         coords,
@@ -220,8 +292,25 @@ def panes(x,
                             wspace=  0.6                              if wspace is not None else wspace,
                             hspace=  0.35                             if hspace is not None else hspace)
 
+        # Retrieve curve arguments
+        _cargs = {}
+        for k in cargs.keys():
+            _curve_arg = cargs[k]
+            if isinstance(_curve_arg, list):
+                # multiple curves per panel -> plural argument to comparison
+                if len(_curve_arg) == n_plots and all([isinstance(_arg, list) for _arg in _curve_arg]):
+                    # each panel is passed a different list of curve arguments
+                    _cargs[k] = _curve_arg[n]
+                else:
+                    # the same list of curve arguments is passed to all panels
+                    _cargs[k] = _curve_arg
+            else:
+                # single curve per panel
+                _k = k[:-3] + k[-2:] if ax_arg(k) else k[:-1]
+                _cargs[_k] = _curve_arg
+
         # Pass keyword arguments to last
-        args = {**kwargs, **plural(n), **cargs} if n != n_plots - 1 else {**kwargs, **plural(n), **cargs, **fargs, **largs}
+        args = {**kwargs, **plural(n), **_cargs} if n != n_plots - 1 else {**kwargs, **plural(n), **_cargs, **fargs, **largs}
 
         # If y[n] is a list (multiple curves in each plot)
         if isinstance(y[n], list) and isinstance(x[n], list):
@@ -286,4 +375,4 @@ def panes(x,
                     bbox_extra_artists=legend,
                     )
     if show:
-        plt.show()
\ No newline at end of file
+        plt.show()
